import c4d

from smarthnoptions import ids
from smarthnoptions import worker
    

class MainDialog(c4d.gui.GeDialog):
       
    # called once when the dialog is initialized
    def __init__(self): 
        
        # kill the menu-bar
        self.AddGadget(c4d.DIALOG_NOMENUBAR, ids.MAINDIALOG);
        
        
    # called when the dialog is opened - load or generate the GUI here
    def CreateLayout(self):  
        
        # load and parse the dialog layout from the resource file
        return self.LoadDialogResource(ids.MAINDIALOG, None, flags= c4d.BFH_SCALEFIT | c4d.BFV_SCALEFIT )         
    

    # called after 'CreateLayout()' - used to initialize the GUI elements 
    #and reset values
    def InitValues(self): 
        
        # init the sliders
        self.SetReal(ids.MAINDIALOG_SLIDER_EDITOR, 2, 0, 6, 1.0, c4d.FORMAT_LONG)
        self.SetReal(ids.MAINDIALOG_SLIDER_RENDER, 3, 0, 6, 1.0, c4d.FORMAT_LONG)

        # disable elements that are dependent on checkbox-settings
        self.Enable(ids.MAINDIALOG_SLIDER_EDITOR, False)
        self.Enable(ids.MAINDIALOG_SLIDER_RENDER, False)
        self.Enable(ids.MAINDIALOG_RADIO_GRP, False)
        
        # set the radio-button group to the first option by default
        self.SetLong(ids.MAINDIALOG_RADIO_GRP, ids.MAINDIALOG_RADIO_DALL)
               
        return True
    
    
    # called on every GUI-interaction - check the 'id' against those of
    #your GUI elements
    def Command(self, id, msg):  
              
        # "Ok"
        if id == 1:   
            enableState = 0
            # collect the needed parameters and...
            if self.GetBool(ids.MAINDIALOG_CHECK_ENABLE):
                if self.GetLong(ids.MAINDIALOG_RADIO_GRP) == ids.MAINDIALOG_RADIO_DALL:
                    enableState = 1
                        
                if self.GetLong(ids.MAINDIALOG_RADIO_GRP) == ids.MAINDIALOG_RADIO_EALL:
                    enableState = 2
                        
                if self.GetLong(ids.MAINDIALOG_RADIO_GRP) == ids.MAINDIALOG_RADIO_SALL:
                    enableState = 3    
            
            # ...start the worker.
            result = worker.work(aEnabledState  = enableState, 
                                 aSetEditor     = self.GetBool(ids.MAINDIALOG_CHECK_SETEDITOR),
                                 aSetRender     = self.GetBool(ids.MAINDIALOG_CHECK_SETRENDER),
                                 aEditor        = self.GetLong(ids.MAINDIALOG_SLIDER_EDITOR),
                                 aRender        = self.GetLong(ids.MAINDIALOG_SLIDER_RENDER),
                                 aInc           = self.GetBool(ids.MAINDIALOG_CHECK_INC))
            
            """
            # nag the user if there are no HyperNURBS objects.
            if not result:
                c4d.gui.MessageDialog(c4d.plugins.GeLoadString(ids.STR_NONEFOUND))
            """
           
        # "Cancel"
        if id == 2:   
            # just close the dialog - this will call 'AskClose()' first (see bottom)
            self.Close()  
           
        # "Set editor subdivisions" 
        if id == ids.MAINDIALOG_CHECK_SETEDITOR:
            # enable/disable the editor-subdivision slider with this checkbox state
            self.Enable(ids.MAINDIALOG_SLIDER_EDITOR, self.GetBool(ids.MAINDIALOG_CHECK_SETEDITOR))
        
        # "Set render subdivisions"
        if id == ids.MAINDIALOG_CHECK_SETRENDER:
            # enable/disable the render-subdivision slider with this checkbox state
            self.Enable(ids.MAINDIALOG_SLIDER_RENDER, self.GetBool(ids.MAINDIALOG_CHECK_SETRENDER))
            
        # "Add/Subtract value"
        if id == ids.MAINDIALOG_CHECK_INC:
            #set the slider ranges to allow for negative values if subtraction is enabled
            self.SetReal(ids.MAINDIALOG_SLIDER_EDITOR, 2, -6 if self.GetBool(ids.MAINDIALOG_CHECK_INC) else 0, 6, 1.0, c4d.FORMAT_LONG)
            self.SetReal(ids.MAINDIALOG_SLIDER_RENDER, 3, -6 if self.GetBool(ids.MAINDIALOG_CHECK_INC) else 0, 6, 1.0, c4d.FORMAT_LONG)
            
        # "Set enabled state"
        if id == ids.MAINDIALOG_CHECK_ENABLE:
            #enable/disable the state-radiobuttons with this checkbox state
            self.Enable(ids.MAINDIALOG_RADIO_GRP, self.GetBool(ids.MAINDIALOG_CHECK_ENABLE))
               
        return True   
    
    """
    # called on 'Close()'
    def AskClose(self):
        
        return not c4d.gui.QuestionDialog(c4d.plugins.GeLoadString(ids.STR_ASKCLOSE))
    """       